Skip to contents

A high-performance R package for cell-cell communication (CCC) analysis in single-cell RNA sequencing data. FastCCCR implements an innovative statistical framework based on exact null distribution computation, Cauchy combination of multiple statistical methods, and reference-based inference.

Main Functions

Visualization

Supported Databases

  • CellPhoneDB v4.1.0, v5.0.0

  • CellChat v1.6.1

  • NicheNet v1.1.1, v2.1.5

Seurat Compatibility

FastCCCR supports both Seurat V4 and V5 objects. The package automatically detects the Seurat version and uses the appropriate methods.

References

Liu, Z. et al. (2026). FastCCCR: Fast Cell-Cell Communication Analysis with Statistical Framework.

Author

Zaoqu Liu liuzaoqu@163.com